@@ -8,8 +8,9 @@ import fsspec
 import numpy as np
 import pandas as pd
 import xarray as xr
+from ocf_datapipes.utils.consts import BatchKey
 
-from power_perceiver.consts import BatchKey, Location
+from power_perceiver.consts import Location
 from power_perceiver.exceptions import NoPVSystemsInSlice
 from power_perceiver.geospatial import lat_lon_to_osgb
 from power_perceiver.load_prepared_batches.data_sources.prepared_data_source import NumpyBatch
